Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2203)

Unified Diff: chrome/browser/renderer_host/render_widget_host.h

Issue 21485: Bitmap transport (Closed)
Patch Set: Fix some mac crashes Created 11 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/renderer_host/render_widget_host.h
diff --git a/chrome/browser/renderer_host/render_widget_host.h b/chrome/browser/renderer_host/render_widget_host.h
index 48fc91275cff83581ba4c38faf7a939a7f927bc1..8c8f0076cda31e7d47f37db10ac1a4c9cd03d82f 100644
--- a/chrome/browser/renderer_host/render_widget_host.h
+++ b/chrome/browser/renderer_host/render_widget_host.h
@@ -9,7 +9,6 @@
#include "base/gfx/size.h"
#include "base/timer.h"
-#include "chrome/common/bitmap_wire_data.h"
#include "chrome/common/ipc_channel.h"
#include "testing/gtest/include/gtest/gtest_prod.h"
@@ -21,6 +20,7 @@ class BackingStore;
class PaintObserver;
class RenderProcessHost;
class RenderWidgetHostView;
+class TransportDIB;
class WebInputEvent;
class WebKeyboardEvent;
class WebMouseEvent;
@@ -262,14 +262,14 @@ class RenderWidgetHost : public IPC::Channel::Listener {
void OnMsgImeUpdateStatus(int control, const gfx::Rect& caret_rect);
// Paints the given bitmap to the current backing store at the given location.
- void PaintBackingStoreRect(BitmapWireData bitmap,
+ void PaintBackingStoreRect(TransportDIB* dib,
const gfx::Rect& bitmap_rect,
const gfx::Size& view_size);
// Scrolls the given |clip_rect| in the backing by the given dx/dy amount. The
// |bitmap| and its corresponding location |bitmap_rect| in the backing store
// is the newly painted pixels by the renderer.
- void ScrollBackingStoreRect(BitmapWireData bitmap,
+ void ScrollBackingStoreRect(TransportDIB* dib,
const gfx::Rect& bitmap_rect,
int dx, int dy,
const gfx::Rect& clip_rect,
@@ -262,14 +262,14 @@ class RenderWidgetHost : public IPC::Channel::Listener {
const gfx::Size& view_size);
// Scrolls the given |clip_rect| in the backing by the given dx/dy amount. The
- // |bitmap| and its corresponding location |bitmap_rect| in the backing store
+ // |dib| and its corresponding location |bitmap_rect| in the backing store
// is the newly painted pixels by the renderer.

Powered by Google App Engine
This is Rietveld 408576698